import os
import sys
import shutil

###############################################################################
# Settings are in file settings.py
###############################################################################
from settings import *

###############################################################################
# Don't edit below
###############################################################################

longest_sequence = sorted(sequence_lengths)[-1]

def copylink(source, dest):
	if create_symlinks:
		try:
			os.symlink(source, dest)
		except:
			pass
	else:
		shutil.copy(source, dest)

if not os.path.exists(image_path) or not os.path.isdir(image_path):
	sys.stderr.write('Image path "%s" not found.\n' % image_path)
	sys.exit(1)

for sl in sequence_lengths:
	tld = os.path.join(root_path, 'sequencelength%02d' % sl)
	
	if not os.path.exists(tld):
		print('"%s" skipped.' % tld)
		continue
	
	for i in xrange(max_sets):
		set_dir = os.path.join(tld, 'set%02d' % i)
		
		if not os.path.exists(set_dir):
			print('"%s" skipped.' % set_dir)
			continue
		
		for j in xrange(sl):
			fn_txt   = 'lowres%03d.txt'       % (i * longest_sequence + j)
			fn_range = 'lowres%03d_range.png' % (i * longest_sequence + j)
			fn_gray  = 'lowres%03d_gray.png'  % (i * longest_sequence + j)
			fn_flag  = 'lowres%03d_flag.png'  % (i * longest_sequence + j)
			
			fn_txt_dst   = 'lowres%03d.txt'       % j
			fn_range_dst = 'lowres%03d_range.png' % j
			fn_gray_dst  = 'lowres%03d_gray.png'  % j
			fn_flag_dst  = 'lowres%03d_flag.png'  % j
			
			copylink(os.path.join(image_path, fn_txt),   os.path.join(set_dir, fn_txt_dst))
			copylink(os.path.join(image_path, fn_range), os.path.join(set_dir, fn_range_dst))
			copylink(os.path.join(image_path, fn_gray),  os.path.join(set_dir, fn_gray_dst))
			copylink(os.path.join(image_path, fn_flag),  os.path.join(set_dir, fn_flag_dst))
		